"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var tslib_1 = require("tslib");
var index_1 = require("./index");
var hls_1 = (0, tslib_1.__importDefault)(require("./adapters/hls"));
var dash_1 = (0, tslib_1.__importDefault)(require("./adapters/dash"));
var subtitles_1 = (0, tslib_1.__importDefault)(require("./modules/ui/subtitles/subtitles"));
var chromecast_1 = (0, tslib_1.__importDefault)(require("./modules/ui/controls/chromecast/chromecast"));
var chromecast_manager_1 = (0, tslib_1.__importDefault)(require("./modules/chromecast-manager/chromecast-manager"));
var DEFAULT_URLS = {
    DASH: 'https://dash.akamaized.net/akamai/bbb_30fps/bbb_30fps.mpd',
    HLS: 'https://files.wixstatic.com/files/video/64b2fa_039e5c16db504dbaad166ba28d377744/repackage/hls',
    MP4: 'https://storage.googleapis.com/video-player-media-server-static/test2.mp4',
    'MP4-VERTICAL': 'https://storage.googleapis.com/video-player-media-server-static/videoplayback.mp4',
    /**
     * start LIVE media
     *
     * Flow:
     * go to https://video-player-media-server-dot-wixgamma.appspot.com
     * click START
     */
    LIVE: 'https://video-player-media-server-dot-wixgamma.appspot.com/live/stream/manifest.m3u8',
};
(0, index_1.registerModule)('subtitles', subtitles_1.default);
(0, index_1.registerModule)('chromecastManager', chromecast_manager_1.default);
(0, index_1.registerModule)('chromecastButton', chromecast_1.default);
(0, index_1.registerPlaybackAdapter)(hls_1.default);
(0, index_1.registerPlaybackAdapter)(dash_1.default);
var config = {
    framesCount: 178,
    qualities: [
        {
            spriteUrlMask: 'https://storage.googleapis.com/video-player-media-server-static/thumbnails/low_rez_sprite_%d.jpg',
            frameSize: { width: 90, height: 45 },
            framesInSprite: { vert: 10, horz: 10 },
        },
        {
            spriteUrlMask: 'https://storage.googleapis.com/video-player-media-server-static/thumbnails/high_rez_sprite_%d.jpg',
            frameSize: { width: 180, height: 90 },
            framesInSprite: { vert: 5, horz: 5 },
        },
    ],
};
document.addEventListener('DOMContentLoaded', function () {
    var player = (0, index_1.create)({
        preload: index_1.PRELOAD_TYPES.METADATA,
        width: 600,
        height: 350,
        playsinline: true,
        rtl: false,
    });
    player.showLogo();
    Object.defineProperty(window, 'player', {
        value: player,
    });
    var selectVideo = function (type, url) {
        player.setSrc({
            type: type,
            url: url || DEFAULT_URLS[type],
        });
        player.setTitle("".concat(type, " format"));
    };
    selectVideo(index_1.MEDIA_STREAM_TYPES.HLS);
    document.getElementById('types').addEventListener('click', function (event) {
        var type = event.target.dataset.type;
        if (!type) {
            return;
        }
        if (type === 'MP4-VERTICAL' || type === 'LIVE') {
            player.setSrc({
                type: type === 'LIVE' ? index_1.MEDIA_STREAM_TYPES.HLS : index_1.MEDIA_STREAM_TYPES.MP4,
                url: DEFAULT_URLS[type],
            });
            player.setTitle("".concat(type));
        }
        else {
            selectVideo(type);
        }
    });
    document.getElementById('theme-switcher').addEventListener('click', function (event) {
        var color = event.target.dataset.color;
        if (!color) {
            return;
        }
        player.updateTheme({ progressColor: color, color: color });
    });
    document
        .getElementById('progress-bar-modes')
        .addEventListener('click', function (event) {
        var mode = event.target.dataset.mode;
        if (!mode) {
            return;
        }
        if (mode === 'REGULAR') {
            player.seekOnProgressDrag();
        }
        else if (mode === 'PREVIEW') {
            player.showPreviewOnProgressDrag();
        }
    });
    Array.from(document.querySelectorAll('[name="direction"]')).forEach(function (radioInput) {
        radioInput.addEventListener('change', function (e) {
            player.setRtl(e.target.value === 'rtl');
        });
    });
    player.attachToElement(document.getElementById('player-wrapper'));
    player.setFramesMap(config);
    player.showLiveIndicator();
});
//# sourceMappingURL=develop.js.map