"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var tslib_1 = require("tslib");
var index_1 = (0, tslib_1.__importDefault)(require("../index"));
var environment_detection_1 = require("../utils/environment-detection");
var hls_1 = (0, tslib_1.__importDefault)(require("../adapters/hls"));
var dash_1 = (0, tslib_1.__importDefault)(require("../adapters/dash"));
/* ignore coverage */
describe('Playback e2e test', function () {
    index_1.default.registerPlaybackAdapter(hls_1.default);
    index_1.default.registerPlaybackAdapter(dash_1.default);
    this.timeout(10000);
    var container = document.createElement('div');
    var formatsToTest = [
        {
            type: 'MP4',
            url: 'https://storage.googleapis.com/video-player-media-server-static/sample.mp4',
            supportedByEnv: environment_detection_1.NativeEnvironmentSupport.MP4,
        },
        {
            type: 'WEBM',
            url: 'https://storage.googleapis.com/video-player-media-server-static/sample.webm',
            supportedByEnv: environment_detection_1.NativeEnvironmentSupport.WEBM,
        },
        {
            type: 'HLS',
            url: 'https://storage.googleapis.com/video-player-media-server-static/sample.m3u8',
            supportedByEnv: environment_detection_1.NativeEnvironmentSupport.HLS || environment_detection_1.NativeEnvironmentSupport.MSE,
        },
        {
            type: 'DASH',
            url: 'https://storage.googleapis.com/video-player-media-server-static/sample.mpd',
            supportedByEnv: environment_detection_1.NativeEnvironmentSupport.DASH || environment_detection_1.NativeEnvironmentSupport.MSE,
        },
        {
            type: 'DASH or HLS',
            url: [
                'https://storage.googleapis.com/video-player-media-server-static/sample.m3u8',
                'https://storage.googleapis.com/video-player-media-server-static/sample.mpd',
            ],
            supportedByEnv: environment_detection_1.NativeEnvironmentSupport.HLS ||
                environment_detection_1.NativeEnvironmentSupport.DASH ||
                environment_detection_1.NativeEnvironmentSupport.MSE,
        },
    ];
    formatsToTest.forEach(function (formatToTest) {
        if (formatToTest.supportedByEnv) {
            it("allows playback of ".concat(formatToTest.type), function (done) {
                // TODO: describe `@playerApi` methods in `Player` with TS
                var player = index_1.default.create();
                player.attachToElement(container);
                player.on(index_1.default.ENGINE_STATES.PLAYING, function () {
                    player.destroy();
                    done();
                });
                player.setSrc(formatToTest.url);
                player.play();
            });
            it("allows playback of ".concat(formatToTest.type, " when preload = none"), function (done) {
                var player = index_1.default.create({
                    preload: index_1.default.PRELOAD_TYPES.NONE,
                });
                player.attachToElement(container);
                player.on(index_1.default.ENGINE_STATES.PLAYING, function () {
                    player.destroy();
                    done();
                });
                player.on(index_1.default.VIDEO_EVENTS.PLAY_ABORTED, function () {
                    player.destroy();
                    done();
                });
                player.setSrc(formatToTest.url);
                player.play();
            });
        }
    });
});
//# sourceMappingURL=playback-test-with-adapters.js.map