"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var tslib_1 = require("tslib");
require("jsdom-global/register");
var chai_1 = require("chai");
var sinon = (0, tslib_1.__importStar)(require("sinon"));
var testkit_1 = (0, tslib_1.__importDefault)(require("../../../../testkit"));
var constants_1 = require("../../../../constants");
var FullScreenManagerMock = /** @class */ (function () {
    function FullScreenManagerMock() {
        this.enterFullScreen = function () { };
        this.exitFullScreen = function () { };
        this.isEnabled = true;
        this._config = {};
    }
    return FullScreenManagerMock;
}());
describe('FullScreenControl', function () {
    var testkit;
    var control = {};
    var eventEmitter = {};
    var fullScreenManager = {};
    beforeEach(function () {
        testkit = (0, testkit_1.default)();
        testkit.registerModuleAsSingleton('fullScreenManager', FullScreenManagerMock);
        fullScreenManager = testkit.getModule('fullScreenManager');
        eventEmitter = testkit.getModule('eventEmitter');
        control = testkit.getModule('fullScreenControl');
    });
    describe('constructor', function () {
        it('should create instance ', function () {
            (0, chai_1.expect)(control).to.exist;
            (0, chai_1.expect)(control.view).to.exist;
        });
    });
    describe('ui events listeners', function () {
        it('should call callback on playback state change', function () {
            return (0, tslib_1.__awaiter)(this, void 0, void 0, function () {
                var spy;
                return (0, tslib_1.__generator)(this, function (_a) {
                    switch (_a.label) {
                        case 0:
                            spy = sinon.spy(control.view, 'setFullScreenState');
                            control._bindEvents();
                            return [4 /*yield*/, eventEmitter.emitAsync(constants_1.UIEvent.FULL_SCREEN_STATE_CHANGED)];
                        case 1:
                            _a.sent();
                            (0, chai_1.expect)(spy.called).to.be.true;
                            return [2 /*return*/];
                    }
                });
            });
        });
    });
    describe('API', function () {
        it('should have method for showing whole view', function () {
            (0, chai_1.expect)(control.show).to.exist;
            control.show();
            (0, chai_1.expect)(control.isHidden).to.be.false;
        });
        it('should have method for hiding whole view', function () {
            (0, chai_1.expect)(control.hide).to.exist;
            control.hide();
            (0, chai_1.expect)(control.isHidden).to.be.true;
        });
        it('should have method for destroying', function () {
            var spy = sinon.spy(control, '_unbindEvents');
            (0, chai_1.expect)(control.destroy).to.exist;
            control.destroy();
            (0, chai_1.expect)(spy.called).to.be.true;
        });
    });
    describe('internal methods', function () {
        it('should call callbacks from uiView', function () {
            var enterSpy = sinon.spy(fullScreenManager, 'enterFullScreen');
            var exitSpy = sinon.spy(fullScreenManager, 'exitFullScreen');
            control._toggleFullScreen();
            (0, chai_1.expect)(enterSpy.called).to.be.true;
            fullScreenManager.isInFullScreen = true;
            control._toggleFullScreen();
            (0, chai_1.expect)(exitSpy.called).to.be.true;
            fullScreenManager.enterFullScreen.restore();
            fullScreenManager.exitFullScreen.restore();
        });
    });
});
//# sourceMappingURL=full-screen.spec.js.map