"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.eventType = exports.SessionState = exports.WindowChromeAPIMock = exports.WindowCastAPIMock = exports.CastTestFramework = void 0;
var tslib_1 = require("tslib");
var SessionState;
(function (SessionState) {
    SessionState["NO_SESSION"] = "NO_SESSION";
    SessionState["SESSION_STARTING"] = "SESSION_STARTING";
    SessionState["SESSION_STARTED"] = "SESSION_STARTED";
    SessionState["SESSION_START_FAILED"] = "SESSION_START_FAILED";
    SessionState["SESSION_ENDING"] = "SESSION_ENDING";
    SessionState["SESSION_ENDED"] = "SESSION_ENDED";
    SessionState["SESSION_RESUMED"] = "SESSION_RESUMED";
})(SessionState || (SessionState = {}));
exports.SessionState = SessionState;
var eventType;
(function (eventType) {
    eventType["CAST_STATE_CHANGED"] = "caststatechanged";
    eventType["SESSION_STATE_CHANGED"] = "sessionstatechanged";
})(eventType || (eventType = {}));
exports.eventType = eventType;
var RemotePlayerEventType;
(function (RemotePlayerEventType) {
    RemotePlayerEventType["ANY_CHANGE"] = "anyChanged";
    RemotePlayerEventType["IS_PAUSED_CHANGED"] = "isPausedChanged";
})(RemotePlayerEventType || (RemotePlayerEventType = {}));
var Publisher = /** @class */ (function () {
    function Publisher() {
        this._listeners = {};
    }
    Publisher.prototype.addEventListener = function (type, func) {
        if (!Array.isArray(this._listeners[type])) {
            this._listeners[type] = [];
        }
        this._listeners[type].push(func);
    };
    Publisher.prototype.trigger = function (type, event) {
        var listeners = this._listeners[type];
        if (listeners) {
            listeners.forEach(function (l) { return l(event); });
        }
    };
    return Publisher;
}());
var CastContext = /** @class */ (function (_super) {
    (0, tslib_1.__extends)(CastContext, _super);
    function CastContext() {
        var _this = _super !== null && _super.apply(this, arguments) || this;
        _this._estimatedTime = 0;
        return _this;
    }
    Object.defineProperty(CastContext.prototype, "list", {
        get: function () {
            return this._listeners;
        },
        enumerable: false,
        configurable: true
    });
    CastContext.prototype.getCurrentSession = function () {
        var _this = this;
        return {
            getMediaSession: function () { return ({
                getEstimatedTime: function () { return _this._estimatedTime; },
            }); },
        };
    };
    CastContext.prototype.setOptions = function () {
        return;
    };
    return CastContext;
}(Publisher));
var RemotePlayer = /** @class */ (function () {
    function RemotePlayer() {
        this.currentTime = 0;
    }
    return RemotePlayer;
}());
var RemotePlayerController = /** @class */ (function (_super) {
    (0, tslib_1.__extends)(RemotePlayerController, _super);
    function RemotePlayerController(player) {
        var _this = _super.call(this) || this;
        _this.player = player;
        return _this;
    }
    RemotePlayerController.prototype.setVolumeLevel = function () {
        return;
    };
    RemotePlayerController.prototype.seek = function () {
        return;
    };
    return RemotePlayerController;
}(Publisher));
var CastTestFramework = /** @class */ (function () {
    function CastTestFramework() {
        this._context = new CastContext();
        this.RemotePlayerController = RemotePlayerController;
        this.RemotePlayer = RemotePlayer;
    }
    CastTestFramework.prototype.trigger = function (type, event) {
        this._context.trigger(type, event);
    };
    Object.defineProperty(CastTestFramework.prototype, "CastContext", {
        get: function () {
            var _this = this;
            return {
                getInstance: function () { return _this._context; },
            };
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(CastTestFramework.prototype, "CastContextEventType", {
        get: function () {
            return eventType;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(CastTestFramework.prototype, "SessionState", {
        get: function () {
            return SessionState;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(CastTestFramework.prototype, "RemotePlayerEventType", {
        get: function () {
            return RemotePlayerEventType;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(CastTestFramework.prototype, "context", {
        get: function () {
            return this._context;
        },
        enumerable: false,
        configurable: true
    });
    return CastTestFramework;
}());
exports.CastTestFramework = CastTestFramework;
var WindowCastAPIMock = /** @class */ (function () {
    function WindowCastAPIMock() {
        this.framework = new CastTestFramework();
    }
    WindowCastAPIMock.init = function () {
        var w = window;
        if (w && typeof w.__onGCastApiAvailable === 'function') {
            w.__onGCastApiAvailable(true);
        }
    };
    WindowCastAPIMock.reset = function () {
        var w = window;
        delete w.__onGCastApiAvailable;
    };
    return WindowCastAPIMock;
}());
exports.WindowCastAPIMock = WindowCastAPIMock;
var WindowChromeAPIMock = /** @class */ (function () {
    function WindowChromeAPIMock() {
    }
    Object.defineProperty(WindowChromeAPIMock.prototype, "cast", {
        get: function () {
            return {
                media: {
                    DEFAULT_MEDIA_RECEIVER_APP_ID: 'mock',
                },
                AutoJoinPolicy: {
                    ORIGIN_SCOPED: true,
                },
            };
        },
        enumerable: false,
        configurable: true
    });
    return WindowChromeAPIMock;
}());
exports.WindowChromeAPIMock = WindowChromeAPIMock;
//# sourceMappingURL=chomecast-api-mock.js.map