import { IPictureInPicture, IPictureInPictureAPI } from './types';
import { IEventEmitter } from '../event-emitter/types';
import { IPlaybackEngine } from '../playback-engine/types';
declare class PictureInPicture implements IPictureInPicture {
    static moduleName: string;
    static dependencies: string[];
    private _eventEmitter;
    private _helper;
    private _isEnabled;
    constructor({ eventEmitter, engine, }: {
        engine: IPlaybackEngine;
        eventEmitter: IEventEmitter;
    });
    private _onChange;
    /**
     * Player would try to enter fullscreen mode.
     * Behavior of fullscreen mode on different platforms may differ.
     * @example
     * player.enterFullScreen();
     */
    enterPictureInPicture(): void;
    /**
     * Player would try to exit fullscreen mode.
     * @example
     * player.exitFullScreen();
     */
    exitPictureInPicture(): void;
    /**
     * Disable functionality for entering picture in picture mode
     * @example
     * player.disablePictureInPicture();
     */
    disablePictureInPicture(): void;
    /**
     * Enable functionality for entering picture in picture mode
     * @example
     * player.enablePictureInPicture();
     */
    enablePictureInPicture(): void;
    /**
     * Return true if player is in picture in picture mode
     * @example
     * console.log(player.isInPictureInPicture); // false
     */
    get isInPictureInPicture(): boolean;
    get isEnabled(): boolean;
    destroy(): void;
}
export { IPictureInPictureAPI };
export default PictureInPicture;
